@@ -12,7 +12,7 @@ class Biofeature:
     def call(self, img: str, cpf: Union[None, str] = None) -> dict:
         response = self.client.request(
             "post", f"{api_urls['biofeatureai']}/predict", files={"file": open(img, 'rb')}, json={"cpf": cpf})
-        if not response.status_code == 201:
+        if not (response.status_code == 201 or response.status_code == 422):
             raise Exception(f"[Error] Prediction failed. {response.content}")
         return response.json()
 
