@@ -12,7 +12,4 @@ class Client:
         response = getattr(requests, method)(route, **kwargs)
         if response.status_code == 401:
             raise Exception("Not authorized! Please verify if your token is correct and if you have access to this service.")
-        if not response:
-            raise Exception(
-                f"[Error] Cannot query server for route {route}. {response.content}")
         return response
